import platform
import click
import subprocess

def __exec_macos(args):
    return subprocess.run(args)

def check_command_installed(command):
    return subprocess.run(["command", "-v", command]).returncode == 0

def exec(commands):
    if platform.system() == 'Darwin':
        return __exec_macos(commands)
    elif platform.system() == 'Windows':
        click.echo("Windows not currently supported")
        exit(1)
    else:
        click.echo('Platform Unsupported')
        exit(1)

def exec_powershell_script(script, *args):
    command = ["pwsh", script] + list(args)
    print (command)
    exec(command)

def exec_powershell_command(*args):
    command = ["pwsh", "-c", args]
    if platform.system() == 'Darwin':
        click.echo("Running Command: ")
        click.echo(command)
        subprocess.run(command)
    elif platform.system() == 'Windows':
        pass
    else:
        click.echo('Platform Unsupported')
        exit(1)

    click.echo(args)



import click
import csv
import re
import os
import tempfile

import teams_import
from teams_import import shell

try:
    import importlib.resources as pkg_resources

except ImportError:
    import importlib_resources as pkg_resources

temp = tempfile.NamedTemporaryFile(mode="w+", suffix='.csv')
print(temp.name)

def invite():
    if os.path.isfile("./import.ps1"):
        shell.exec_powershell_script("./import.ps1")
    else:
        print("Can't find import powershell file")


def getUnitcodeFromDisplayName(displayName):
    m = re.search('SIT[0-9]{3}', displayName)
    if m:
        return m.group(0)
    else:
        click.echo("No valid unit code in: " + displayName)
        return None


def generateImport(csvsDir, dict, email):

    not_found = []
    found = []
    f = open("import.ps1", "w+")
    for key, value in dict.items():
        file_path = f"{csvsDir}/{key}.csv"
        if os.path.isfile(file_path):
            found.append(f"Preparing import for {file_path}")
            print(
                "Import-Module MicrosoftTeams\n"
                f"Connect-MicrosoftTeams\n"
                f"Import-Csv -Path {file_path} | ForEach-Object {{Add-TeamUser -GroupId {value} -user $_.email}}\n")
            f.write(
                "Import-Module MicrosoftTeams\n"
                f"Connect-MicrosoftTeams\n"
                f"Import-Csv -Path {file_path} | ForEach-Object {{Add-TeamUser -GroupId {value} -user $_.email}}\n")
        else:
            not_found.append(f"No CSV file found at {file_path}")

    print("\n".join(found))
    print("\n".join(not_found))


def process(csvsDir, email):
    dict = {}
    with open(temp.name, mode='r') as csvfile:
        reader = csv.DictReader(csvfile)
        for row in reader:
            unitCode = getUnitcodeFromDisplayName((row['DisplayName']))
            if unitCode:
                dict[unitCode] = row['GroupId']
    generateImport(csvsDir, dict, email)


def init(email):
    result = shell.check_command_installed("pwsh")
    if not result:
        exit(2)
    else:
        with pkg_resources.path('teams_import.templates', 'install-teams.ps1') as file:
            shell.exec_powershell_script(file, email, temp.name)


@click.command()
@click.argument('csvsDir', type=click.Path(exists=True))
@click.argument('email', required=True)
def cli(csvsdir, email):
    """The CLI tool for importing Deakin students into Microsoft teams"""
    init(email)
    process(csvsdir, email)
    invite()



import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

setup(
    description="A command line tool for bulk importing students to MicrosoftTeams",
    long_description=README,
    long_description_content_type="text/markdown",
    author="Jake Renzella",
    author_email="jake.renzella@deakin.edu.au",
    license="MIT",
    name='teams-import',
    version='1.0.8b2',
    py_modules=['main'],
    packages=['teams_import'],
    install_requires=[
        'click',
    ],
    include_package_data=True,
    entry_points={
        "console_scripts": [
            "teams-import=teams_import.__main__:cli",
        ]
    }
)
